==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+54"/>
        <source>&amp;Layer</source>
        <translation>P&amp;last</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+136"/>
        <source>Leading or trailing spaces.</source>
        <translation>Presledki spredaj ali zadaj.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>Ime plasti je prazno.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>Plast že obstaja.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>Podatki o plasti</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Ime plasti:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Pen</source>
        <translation>Pisalo</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Lineweight:</source>
        <translation>Debelina črte:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Linetype:</source>
        <translation>Tip črte:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Orodja plasti</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Prikaži orodja plasti</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>P&amp;last</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Presledki spredaj ali zadaj.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>Ime plasti je prazno.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>Plast že obstaja.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>Podatki o plasti</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Ime plasti:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Pisalo</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Atributi</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Debelina črte:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Tip črte:</translation>
    </message>
</context>
</TS>
